@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: autogen.sh 3917 2014-06-20 19:57:41Z chrfranke $
+# $Id: autogen.sh 4053 2015-04-14 20:18:50Z chrfranke $
 #
 # Generate ./configure from config.in and Makefile.in from Makefile.am.
 # This also adds files like missing,depcomp,install-sh to the source
@@ -39,20 +39,20 @@ typep()
 }
 
 test -x "$AUTOMAKE" ||
-    AUTOMAKE=`typep automake-1.14` ||
+    AUTOMAKE=`typep automake-1.15` || AUTOMAKE=`typep automake-1.14` ||
     AUTOMAKE=`typep automake-1.13` || AUTOMAKE=`typep automake-1.12` ||
     AUTOMAKE=`typep automake-1.11` || AUTOMAKE=`typep automake-1.10` ||
     AUTOMAKE=`typep automake-1.9` || AUTOMAKE=`typep automake-1.8` ||
     AUTOMAKE=`typep automake-1.7` || AUTOMAKE=`typep automake17` ||
 {
 echo
-echo "You must have at least GNU Automake 1.7 (up to 1.14) installed"
+echo "You must have at least GNU Automake 1.7 (up to 1.15) installed"
 echo "in order to bootstrap smartmontools from SVN. Download the"
 echo "appropriate package for your distribution, or the source tarball"
 echo "from ftp://ftp.gnu.org/gnu/automake/ ."
 echo
 echo "Also note that support for new Automake series (anything newer"
-echo "than 1.14) is only added after extensive tests. If you live in"
+echo "than 1.15) is only added after extensive tests. If you live in"
 echo "the bleeding edge, you should know what you're doing, mainly how"
 echo "to test it before the developers. Be patient."
 exit 1;
@@ -97,7 +97,7 @@ case "$ver" in
     # OK
     ;;
 
-  1.14|1.14.1)
+  1.14|1.14.1|1.15)
     # TODO: Enable 'subdir-objects' in configure.ac
     # For now, suppress 'subdir-objects' forward-incompatibility warning
     test -n "$warnings" || amwarnings="--warnings=no-unsupported"
@@ -108,6 +108,14 @@ case "$ver" in
     echo "Please report success/failure to the smartmontools-support mailing list."
 esac
 
+# Warn if Automake version is too old
+case "$ver" in
+  1.[789]|1.[789].*)
+    echo "WARNING:"
+    echo "The use of GNU Automake version $ver is deprecated.  Support for Automake"
+    echo "versions 1.7 - 1.9.x will be removed in a future release of smartmontools."
+esac
+
 # Install pkg-config macros
 # (Don't use 'aclocal -I m4 --install' to keep support for automake < 1.10)
 test -d m4 || mkdir m4 || exit 1
